#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-5Gfw6V0V1UBLMAG5Feq6LC
key:                  hslua-aeson-2.3.1.1-5Gfw6V0V1UBLMAG5Feq6LC
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  ca35da93b68ca98d0413f8020de16347
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-5Gfw6V0V1UBLMAG5Feq6LC
depends:
    aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-HpPQsoREnwfDz6Qf16RXZ0
    hslua-core-2.3.2-IRJMBmA8dMRJqOJNSy8HHv
    hslua-marshalling-2.3.1-GvCUx1RVtMC54aRDCMpW57 mtl-2.3.1
    scientific-0.3.8.1-5xEN5FH7FNLBtMgMgahhk5 text-2.0.2
    unordered-containers-0.2.20.1-BaP0PevI27VLqsaWB0hjeu
    vector-0.13.2.0-CDuZD6JA02PF3ZzyJqHF4G

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

